package com.bweb.controller;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.BsUserSpreadOilChannel;
import com.hfkj.entity.BsUserSpreadPower;
import com.hfkj.model.ResponseData;
import com.hfkj.model.UserSessionObject;
import com.hfkj.service.spread.BsUserSpreadOilChannelService;
import com.hfkj.service.spread.BsUserSpreadPowerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @className: BsUserSpreadController
 * @author: HuRui
 * @date: 2025/3/31
 **/
@Controller
@RequestMapping(value = "/userSpread")
@Api(value = "个人推广业务")
public class BsUserSpreadController {
    private static Logger log = LoggerFactory.getLogger(BsUserSpreadController.class);
    @Resource
    private BsUserSpreadOilChannelService userSpreadOilChannelService;

    @RequestMapping(value = "/editOilChannel", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "编辑油站渠道")
    public ResponseData editOilChannel(@RequestBody JSONObject body) {
        try {
            if (body == null
                    || body.getInteger("channel") == null
                    || body.getBigDecimal("rebate") == null
                    || body.getBigDecimal("rebateOne") == null
                    || body.getBigDecimal("rebateTwo") == null
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            // 查询渠道
            BsUserSpreadOilChannel channel = userSpreadOilChannelService.getDetailByChannel(body.getInteger("channel"));
            if (channel == null) {
                channel = new BsUserSpreadOilChannel();
                channel.setChannel(body.getInteger("channel"));
            }
            channel.setRebate(body.getBigDecimal("rebate"));
            channel.setRebateOne(body.getBigDecimal("rebateOne"));
            channel.setRebateTwo(body.getBigDecimal("rebateTwo"));
            userSpreadOilChannelService.editData(channel);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getOilChannelDetail", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询油站渠道详情")
    public ResponseData getOilChannelDetail(@RequestParam(value = "id", required = true) Long id) {
        try {

            return ResponseMsgUtil.success(userSpreadOilChannelService.getDetail(id));

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getOilChannelList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询油站渠道列表")
    public ResponseData getOilChannelList(@RequestParam(value = "channel", required = false) Integer channel) {
        try {
            Map<String,Object> param = new HashMap<>();
            param.put("channel", channel);
            return ResponseMsgUtil.success(userSpreadOilChannelService.getList(param));

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

}
