package com.hfkj.service.gas.impl;

import com.hfkj.common.utils.DateUtil;
import com.hfkj.dao.BsGasOrderSpreadMapper;
import com.hfkj.entity.*;
import com.hfkj.service.gas.BsGasOrderSpreadService;
import com.hfkj.service.spread.BsUserSpreadAccountService;
import com.hfkj.service.spread.BsUserSpreadOilChannelService;
import com.hfkj.service.spread.BsUserSpreadRelService;
import com.hfkj.sysenum.spread.UserSpreadAccountRecordSourceTypeEnum;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @className: BsGasOrderSpreadServiceImpl
 * @author: HuRui
 * @date: 2025/4/7
 **/
@Service("gasOrderSpreadService")
public class BsGasOrderSpreadServiceImpl implements BsGasOrderSpreadService {
    @Resource
    private BsGasOrderSpreadMapper gasOrderSpreadMapper;
    @Resource
    private BsUserSpreadRelService userSpreadRelService;
    @Resource
    private BsUserSpreadOilChannelService userSpreadOilChannelService;
    @Resource
    private BsUserSpreadAccountService userSpreadAccountService;
    @Override
    public void editData(BsGasOrderSpread data) {
        data.setUpdateTime(new Date());
        if (data.getId() == null) {
            data.setStatus(1);
            data.setCreateTime(new Date());
            gasOrderSpreadMapper.insert(data);
        } else {
            gasOrderSpreadMapper.updateByPrimaryKey(data);
        }
    }

    @Override
    public void createOrderSpread(BsGasOrder order) {
        // 油站渠道
        BsUserSpreadOilChannel channel = userSpreadOilChannelService.getDetailByChannel(order.getChannelType());
        if (channel != null && order.getUserId() != null) {
            // 查询用户直属上级
            BsUserSpreadRel userSpreadRel = userSpreadRelService.getDetailByUser(order.getUserId());
            if (userSpreadRel != null) {
                BsGasOrderSpread gasOrderSpread = new BsGasOrderSpread();
                gasOrderSpread.setOrderNo(order.getOrderNo());
                gasOrderSpread.setGainsRebateUserId(userSpreadRel.getParentUserId());
                gasOrderSpread.setGainsRebateRate(channel.getRebate());
                gasOrderSpread.setGainsRebateAmount(order.getPayablePrice().multiply(channel.getRebate().divide(new BigDecimal("100"))).setScale(2, BigDecimal.ROUND_HALF_DOWN));

                // 查询一级
                BsUserSpreadRel userSpreadOneRel = userSpreadRelService.getDetailByUser(userSpreadRel.getParentUserId());
                if (userSpreadOneRel != null) {
                    gasOrderSpread.setGainsRebateUserId(userSpreadOneRel.getParentUserId());
                    gasOrderSpread.setGainsRebateRate(channel.getRebateOne());
                    gasOrderSpread.setGainsRebateAmount(order.getPayablePrice().multiply(channel.getRebateOne().divide(new BigDecimal("100"))).setScale(2, BigDecimal.ROUND_HALF_DOWN));

                    // 查询二级
                    BsUserSpreadRel userSpreadTwoRel = userSpreadRelService.getDetailByUser(userSpreadOneRel.getParentUserId());
                    if (userSpreadTwoRel != null) {
                        gasOrderSpread.setGainsRebateUserId(userSpreadTwoRel.getParentUserId());
                        gasOrderSpread.setGainsRebateRate(channel.getRebateTwo());
                        gasOrderSpread.setGainsRebateAmount(order.getPayablePrice().multiply(channel.getRebateTwo().divide(new BigDecimal("100"))).setScale(2, BigDecimal.ROUND_HALF_DOWN));
                    }
                }
                editData(gasOrderSpread);
            }
        }
    }

    @Override
    public BsGasOrderSpread getDetailByOrderNo(String orderNo) {
        BsGasOrderSpreadExample example = new BsGasOrderSpreadExample();
        example.createCriteria().andOrderNoEqualTo(orderNo).andStatusEqualTo(1);
        List<BsGasOrderSpread> list = gasOrderSpreadMapper.selectByExample(example);
        if (!list.isEmpty()) {
            return list.get(0);
        }
        return null;
    }

    @Override
    public void settleOrder(Long userId) throws Exception {
        // 获取结算订单数据
        Map<String,Object> dataParam = new HashMap<>();
        dataParam.put("userId", userId);
        HashMap<String, Object> data = gasOrderSpreadMapper.querySettleOrderList(dataParam);
        // 直属佣金
        BigDecimal gainsRebateAmount = new BigDecimal(""+data.get("gains_rebate_amount"));
        // 一级佣金
        BigDecimal gainsRebateOneAmount = new BigDecimal(""+data.get("gains_rebate_one_amount"));
        // 二级佣金
        BigDecimal gainsRebateTwoAmount = new BigDecimal(""+data.get("gains_rebate_two_amount"));
        // 总佣金
        BigDecimal totalRebateAmount = gainsRebateAmount.add(gainsRebateOneAmount).add(gainsRebateTwoAmount);

        // 佣金大于0充值
        if (totalRebateAmount.compareTo(new BigDecimal("0")) >= 1) {
            Map<String,Object> otherParam = new HashMap<>();
            otherParam.put("sourceContent", data.get("settle_date")+"佣金");
            userSpreadAccountService.increase(userId, totalRebateAmount, UserSpreadAccountRecordSourceTypeEnum.type1,otherParam);
        }
    }

    @Override
    public BigDecimal getNotCashOutAmount(Long userId) {
        return gasOrderSpreadMapper.queryNotCashOutAmount(userId);
    }
}
